KeySettlement

Struct KeySettlement 

pub struct KeySettlement<C> { /* private fields */ }
Client-side key settlement handling

Implementations

Source

impl<C: KeySettlementCore> KeySettlement<C>

pub fn new(core: C) -> Self

pub async fn settle(&mut self, data: &C::Data) -> Result<()>

Settle a new key with the service

Errors

Returns errors if the request fails, the attestation verification fails or the response does not meet the expectations.

Panics

Panics if Base64 values are not valid HTTP header values.

pub fn system_version(&self) -> Option<&PublishedVersionEntry>

System version for the currently established session

pub async fn seal( &mut self, data: &[u8], user_data: &C::Data, ) -> Result<Vec<u8>>

Seal data for the service

Settles a key if none is settled.

Errors

Forwards errors from settle

Panics

Panics if chacha_box_ietf::seal panics.

pub fn try_seal(&self, data: &[u8]) -> Option<Vec<u8>>

Seal data for the service

Returns None if no key is settled.

Panics

Panics if chacha_box_ietf::seal panics.

pub fn unseal(&self, data: &[u8]) -> Result<Vec<u8>, Error>

Unseal data from the service

Errors

Forwards errors from chacha_box_ietf::unseal.

pub async fn session_id(&mut self, user_data: &C::Data) -> Result<&HeaderValue>

Return a settled session ID

Settles a key if none is settled.

Errors

Forwards errors from settle

pub fn try_session_id(&self) -> Option<&HeaderValue>

Return a settled session ID

Returns None if no key is settled.